changeset 28816:03f206c5d91b

Change file name `EBROWSE' to `BROWSE'.
author Gerd Moellmann <gerd@gnu.org>
date Thu, 04 May 2000 21:51:29 +0000
parents 58f8c0da3eb3
children 0c88826ad7fd
files lisp/progmodes/ebrowse.el
diffstat 1 files changed, 9 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/ebrowse.el	Thu May 04 21:50:18 2000 +0000
+++ b/lisp/progmodes/ebrowse.el	Thu May 04 21:51:29 2000 +0000
@@ -53,7 +53,7 @@
 (defcustom ebrowse-search-path nil
   "*List of directories to search for source files in a class tree.
 Elements should be directory names; nil as an element means to try
-to find source files relative to the location of the EBROWSE file loaded."
+to find source files relative to the location of the BROWSE file loaded."
   :group 'ebrowse
   :type '(repeat (choice (const :tag "Default" nil)
                          (string :tag "Directory"))))
@@ -364,12 +364,12 @@
 ;;; Structure definitions
 
 (defstruct (ebrowse-hs (:type vector) :named)
-  "Header structure found at the head of EBROWSE files."
+  "Header structure found at the head of BROWSE files."
   ;; A version string that is compared against the version number of
   ;; the Lisp package when the file is loaded.  This is done to
   ;; detect file format changes.
   version
   ;; Command line options used for producing the EBROWSE file.
   command-line-options
   ;; The following slot is currently not used.  It's kept to keep
   ;; the file format compatible.
@@ -382,7 +382,7 @@
     
 (defstruct (ebrowse-ts (:type vector) :named)
   "Tree structure.
-Following the header structure, an EBROWSE file contains a number
+Following the header structure, an BROWSE file contains a number
 of `ebrowse-ts' structures, each one describing one root class of
 the class hierarchy with all its subclasses."
   ;; A `ebrowse-cs' structure describing the root class.
@@ -508,7 +508,7 @@
 
 
 (defconst ebrowse-version-string "ebrowse 5.0"
-  "Version string expected in EBROWSE files.")
+  "Version string expected in BROWSE files.")
 
 
 (defconst ebrowse-globals-name "*Globals*"
@@ -544,7 +544,7 @@
 
 
 (defvar ebrowse--tags-file-name nil
-  "File from which EBROWSE file was loaded.
+  "File from which BROWSE file was loaded.
 Buffer-local in Ebrowse buffers.")
 
 
@@ -1663,7 +1663,7 @@
 FILE is the file to search the member in.
 FILE is not taken out of STRUC here because the filename in STRUC
 may be nil in which case the filename of the class description is used.
-TAGS-FILE-NAME is the name of the EBROWSE file from which the
+TAGS-FILE-NAME is the name of the BROWSE file from which the
 tree was loaded.
 If VIEW is non-nil, view file else find the file.
 WHERE is either `other-window', `other-frame' or `this-window' and
@@ -1698,7 +1698,7 @@
   "Generate a suitable regular expression for a member or class NAME.
 This is `regexp-quote' for most symbols, except for operator names
 which may contain whitespace.  For these symbols, replace white
-space in the symbol name (generated by EBROWSE) with a regular
+space in the symbol name (generated by BROWSE) with a regular
 expression matching any number of whitespace characters."
   (loop with regexp = (regexp-quote name)
 	with start = 0
@@ -2579,7 +2579,7 @@
 declaration.
 INFO is a list (TREE ACCESSOR MEMBER) describing the member to
 search.
-TAGS-FILE-NAME is the file name of the EBROWSE file."
+TAGS-FILE-NAME is the file name of the BROWSE file."
   (unless header
     (setq header ebrowse--header))
   (unless tags-file-name
@@ -364,12 +364,12 @@
   ;; detect file format changes.
   version
-  ;; Command line options used for producing the EBROWSE file.
+  ;; Command line options used for producing the BROWSE file.
   command-line-options
   ;; The following slot is currently not used.  It's kept to keep